/* Copyright 2009 Patrick Higgins 
 *
 * This file is part of VladNput.
 *
 * VladNput is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * VladNput is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with VladNput.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.vladnput;

import org.vladnput.types.VladType;

abstract class BaseParamValidator {

	// this class is immutable for thread safety

	private final Cardinality cardinality;
	private final VladType type;
	private final Integer maxLog;
	private final String desc;
	private final VladMessages messages;
	private final Boolean sensitive;
	private final Boolean enforce;
	
	BaseParamValidator(Cardinality cardinality,
			VladType type,
			Integer maxLog,
			String desc,
			VladMessages messages,
			Boolean sensitive,
			Boolean enforce)
	{
		this.cardinality = cardinality;
		this.type = type;
		this.maxLog = maxLog;
		this.desc = desc;
		this.messages = messages;
		this.sensitive = sensitive;
		this.enforce = enforce;
	}
	
	abstract boolean matches(String paramName);
	
	Cardinality getCardinality() {
		return cardinality;
	}
	
	VladType getType() {
		return type;
	}
	
	Integer getMaxLog() {
		return maxLog;
	}
	
	VladMessages getMessages() {
		return messages;
	}
	
	String getDesc() {
		return desc;
	}

	Boolean getSensitive() {
		return sensitive;
	}

	Boolean getEnforce() {
		return enforce;
	}

}
