/* Copyright 2009 Patrick Higgins 
 *
 * This file is part of VladNput.
 *
 * VladNput is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * VladNput is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with VladNput.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.vladnput;

interface Cardinality {
	
	static final int VALID = 0;
	static final int MISSING_REQUIRED = 1;
	static final int TOO_MANY = 2;
	static final int TOO_FEW = 3;
	
	int test(int cardinality);
	
	static final Cardinality OPTIONAL = new Cardinality() {
		public int test(int cardinality) {
			assert(cardinality >= 0);
			if (cardinality > 1)
				return TOO_MANY;
			return VALID;
		}
	};
	
	static final Cardinality REQUIRED = new Cardinality() {
		public int test(int cardinality) {
			assert(cardinality >= 0);
			switch (cardinality) {
			case 0: return MISSING_REQUIRED;
			case 1: return VALID;
			default: return TOO_MANY;
			}
		}
	};
	
	static final Cardinality ZERO_OR_MORE = new Cardinality() {
		public int test(int cardinality) {
			assert(cardinality >= 0);
			return VALID;
		}
	};
	
	static final Cardinality ONE_OR_MORE = new Cardinality() {
		public int test(int cardinality) {
			assert(cardinality >= 0);
			if (cardinality == 0)
				return TOO_FEW;
			return VALID;
		}
	};
	
	static final class MinChecker implements Cardinality {
		private final int min;
		MinChecker(int min) {
			this.min = min;
		}
		public int test(int cardinality) {
			assert(cardinality >= 0);
			if (cardinality < min)
				return TOO_FEW;
			return VALID;
		}
	}

	static final class MinMaxChecker implements Cardinality {
		private final int min;
		private final int max;
		MinMaxChecker(int min, int max) {
			this.min = min;
			this.max = max;
		}
		public int test(int cardinality) {
			assert(cardinality >= 0);
			if (cardinality < min)
				return TOO_FEW;
			if (cardinality > max)
				return TOO_MANY;
			return VALID;
		}
	}

}
