/* Copyright 2009 Patrick Higgins 
 *
 * This file is part of VladNput.
 *
 * VladNput is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * VladNput is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with VladNput.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.vladnput;

import org.antlr.runtime.IntStream;
import org.antlr.runtime.RecognitionException;
import org.antlr.runtime.tree.CommonTree;
import org.antlr.runtime.tree.TreeNodeStream;

class LookbackException extends RecognitionException {
	
    LookbackException(IntStream input) {
		super(input);
	}

    LookbackException(IntStream input, int tokensBack) {
		super(input);
		if (tokensBack < 0) {
			TreeNodeStream stream = (TreeNodeStream) input;
			CommonTree node = (CommonTree) stream.LT(tokensBack);
			while (node.getLine() <= 0) { // skip imaginary tokens
				--tokensBack;
				node = (CommonTree) stream.LT(tokensBack);
			}
			extractInfoFromNode(node);
		}
	}

	protected void extractInfoFromNode(CommonTree node) {
		if (node != null) {
			this.charPositionInLine = node.getCharPositionInLine();
			this.line = node.getLine();
			this.token = node.getToken();
		}
	}

}
