/* Copyright 2009 Patrick Higgins 
 *
 * This file is part of VladNput.
 *
 * VladNput is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * VladNput is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with VladNput.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.vladnput;

import java.util.Iterator;
import java.util.List;

import org.antlr.runtime.tree.CommonTree;

import org.vladnput.VladTreeParser.BaseParam;

class MissingInheritedValueException extends TokenException {
	
	private final String name;
	private final List<BaseParam> precedence;
	
	MissingInheritedValueException(String name, CommonTree node, List<BaseParam> precedence) {
		super(node, null);
		this.name = name;
		this.precedence = precedence;
	}
	
	private String precedenceString() {
		StringBuffer b = new StringBuffer();
		BaseParam param = precedence.get(0);
		b.append(param.node.getText()).append(":").append(param.node.getLine()).append(":").append(param.node.getCharPositionInLine());
		for (int i = 1; i < precedence.size(); i++) {
			param = precedence.get(i);
			b.append(", ");
			b.append(param.node.getText()).append(":").append(param.node.getLine()).append(":").append(param.node.getCharPositionInLine());
		}
		return b.toString();
	}
	
	public String getMessage() {
		if (precedence.isEmpty()) {
			return "cannot inherit "+name+" for "+getToken().getText()+": no parents";
		}
		return "missing inherited "+name+" for "+getToken().getText()+": parents: "+precedenceString();
	}

}
