/* Copyright 2009 Patrick Higgins 
 *
 * This file is part of VladNput.
 *
 * VladNput is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * VladNput is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with VladNput.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.vladnput;

import java.util.regex.Pattern;

import org.vladnput.types.VladType;

final class ParamMatchValidator extends BaseParamValidator {
	
	// this class is immutable for thread safety

	private final Pattern pattern;
	
    ParamMatchValidator(Pattern pattern, Cardinality cardinality, Integer maxLog, String desc,
    					VladType type, VladMessages msgs, Boolean sensitive, Boolean enforce)
    {
    	super(cardinality, type, maxLog, desc, msgs, sensitive, enforce);
		this.pattern = pattern;
	}
    
    Pattern getPattern() {
    	return pattern;
    }
	
	public String toString() {
		return "ParamMatchValidator: "+pattern.pattern()+": type="+getType();
	}

	boolean matches(String paramName) {
		return pattern.matcher(paramName).matches();
	}

}
