/* Copyright 2009 Patrick Higgins 
 *
 * This file is part of VladNput.
 *
 * VladNput is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * VladNput is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with VladNput.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.vladnput;

import java.io.PrintWriter;
import java.io.StringWriter;

/**
 * Exception thrown when parsing a Vlad file fails.
 * 
 * @author Patrick Higgins
 */
public class ParseException extends Exception {
	
	private final ParseErrors errors;

	/**
	 * Constructs a parsing exception
	 * @param errors The parsing errors
	 */
	public ParseException(ParseErrors errors) {
		this.errors = errors;
	}

	/**
	 * Gets the parse errors
	 * @return Parse errors
	 */
	public ParseErrors getErrors() {
		return errors;
	}

	/**
	 * Returns a potentially multiline string containing all the errors as
	 * reported by <tt>getErrors().reportErrors(PrintWriter)</tt>.
	 */
	public String getMessage() {
		StringWriter sw = new StringWriter();
		PrintWriter pw = new PrintWriter(sw);
		getErrors().reportErrors(pw);
		pw.close();
		return sw.toString();
	}

}
