/* Copyright 2009 Patrick Higgins 
 *
 * This file is part of VladNput.
 *
 * VladNput is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * VladNput is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with VladNput.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.vladnput;

import javax.servlet.http.HttpServletRequest;

/**
 * This interface can be implemented to customize the way that the request URL
 * and request parameters are matched against the Vlad file.
 * 
 * For example, if an application has an environment-specific prefix on all URLs
 * that needs to be stripped so that a single Vlad file can be used for all
 * environments, the <tt>getPath()</tt> method can be used to strip that prefix.
 * 
 * As an another example, if parameter names are not case sensitive, then the
 * <tt>canonicalizeParam()</tt> method can return a lower case version of the
 * parameter name and all parameters in the Vlad file can be written in
 * lower case to match.
 * 
 * @author Patrick Higgins
 */
public interface RequestCanonicalizer {

	/**
	 * Returns the URL to match against the Vlad file from the given <tt>request</tt>.
	 * 
	 * @param request The request URL to canonicalize
	 * @return Canonical URL
	 */
	String getPath(HttpServletRequest request);
	
	/**
	 * Returns the canonical form of a parameter name. For example, this
	 * could be used to implement case-insensitivity by returning a lower-case
	 * or upper-case name.
	 * 
	 * @param param The parameter name to canonicalize
	 * @return Canonical parameter name
	 */
	String canonicalizeParamName(String param);

}
