/* Copyright 2009 Patrick Higgins 
 *
 * This file is part of VladNput.
 *
 * VladNput is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * VladNput is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with VladNput.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.vladnput;

import org.antlr.runtime.Token;
import org.antlr.runtime.tree.CommonTree;
import org.antlr.runtime.tree.Tree;

class TokenException extends Exception {
	
	protected final Token token;

    TokenException(Token token, Throwable cause) {
		if (cause != null) {
			initCause(cause);
		}
		assert(token.getInputStream() != null);
		this.token = token;
	}

    TokenException(Token token) {
    	this(token, null);
    }
    
    TokenException(Tree tree, Throwable cause) {
		this(((CommonTree) tree).token, cause);
	}
    
    TokenException(Tree tree) {
    	this(tree, null);
    }

    Token getToken() {
		return token;
	}
	
	public String getMessage() {
		Throwable cause = getCause();
		if (cause != null) {
			return cause.getMessage();
		}
		return token.getText();
	}

}
