/* Copyright 2009 Patrick Higgins 
 *
 * This file is part of VladNput.
 *
 * VladNput is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * VladNput is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with VladNput.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.vladnput;

import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

class URLMatcher {
	
	// this class is immutable for thread safety, all instance variables must be final and
	// thread safe
	private final Map<String,URLValidator> urls;
	private final URLMatchValidator[] urlMatches;
	
	URLMatcher(List<URLValidator> url, List<URLMatchValidator> urlMatch) {
		Map<String,URLValidator> map = VladUtil.newHashMap();
		for (URLValidator v : url) {
			map.put(v.getURL(), v);
		}
		
		List<URLMatchValidator> list = VladUtil.newArrayList();
		list.addAll(urlMatch);
		Collections.reverse(list);
		
		this.urls = map.size() > 0 ? map : null;
		this.urlMatches = list.size() > 0 ?
				(URLMatchValidator[]) list.toArray(new URLMatchValidator[list.size()])
				: null;
	}
	
	StringBuffer toString(StringBuffer b, int indent) {
		if (urls != null) {
			for (URLValidator v : urls.values()) {
				v.toString(b, indent);
				b.append("\n");
			}
		}
		for (int i = 0, len = urlMatches == null ? 0 : urlMatches.length; i < len; i++) {
			URLMatchValidator v = urlMatches[i];
			v.toString(b, indent);
			b.append("\n");
		}
		return b;
	}
	
	public String toString() {
		return toString(new StringBuffer(), 0).toString();
	}
	
	List<BaseURLValidator> match(String url) {
		List<BaseURLValidator> list = new ArrayList<BaseURLValidator>(1 + (urlMatches == null ? 0 : urlMatches.length));
		if (urls != null) {
			URLValidator v = (URLValidator) urls.get(url);
			if (v != null)
				list.add(v);
		}
		for (int i = 0, len = urlMatches == null ? 0 : urlMatches.length; i < len; i++) {
			URLMatchValidator v = urlMatches[i];
			if (v.getPattern().matcher(url).matches())
				list.add(v);
		}
		return list;
	}

}
