/* Copyright 2009 Patrick Higgins 
 *
 * This file is part of VladNput.
 *
 * VladNput is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * VladNput is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with VladNput.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.vladnput;

import java.util.Iterator;
import java.util.List;

/**
 * A list of <tt>VladError</tt> objects.
 *
 * @author Patrick Higgins
 */
public class VladErrors implements Iterable<VladError> {
	
	private final List<VladError> errors = VladUtil.newArrayList();
	private boolean enforce = false;

	/**
	 * Add <tt>error</tt> to this list
	 * @param error Error to add
	 */
	public void add(VladError error) {
		errors.add(error);
		enforce |= error.getEnforce();
	}
	
	/**
	 * @return true if there are errors where <tt>getEnforce()</tt> returns true, false otherwise
	 */
	public boolean hasEnforcedErrors() {
		return enforce;
	}
	
	/**
	 * Returns <tt>true</tt> if there are errors, <tt>false</tt> otherwise.
	 * @return <tt>true</tt> if there are errors, <tt>false</tt> otherwise
	 */
	public boolean hasErrors() {
		return !errors.isEmpty();
	}

	/**
	 * Returns the actual errors, which is a list of <tt>VladError</tt> objects.
	 * @return List of <tt>VladError</tt> objects
	 */
	public List<VladError> getErrors() {
		return errors;
	}
	
	/**
	 * Allows iteration over the errors.
	 */
	public Iterator<VladError> iterator() {
		return errors.iterator();
	}

	public String toString() {
		return errors.toString();
	}

}
