/* Copyright 2009 Patrick Higgins 
 *
 * This file is part of VladNput.
 *
 * VladNput is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * VladNput is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with VladNput.  If not, see <http://www.gnu.org/licenses/>.
 */
lexer grammar VladLexer;

@header {
package org.vladnput;
}

@members {

private ParseErrors parseErrors = null;

public void setParseErrors(ParseErrors parseErrors) {
    this.parseErrors = parseErrors;
}

public String getErrorHeader(RecognitionException e) {
    return VladUtil.getSourceLocation(e);
}

public void emitErrorMessage(String msg) {
    parseErrors.add(msg);
}

}

FALSE	:	'false'	;
INCLUDE	:	'include'	;
MESSAGE_DEFAULTS	:	'message_defaults'	;
OPTIONS	:	'options'	;
PARAM	:	'param'	;
PARAM_MATCH	:	'param_match'	;
TRUE	:	'true'	;
TYPE	:	'type'	;
URL	:	'url'	;
URL_MATCH	:	'url_match'	;
COMMA	:	','	;
DOT	:	'.'	;
SEMI	:	';'	;
RPAREN	:	')'	;
LPAREN	:	'('	;
EQUALS	:	'='	;
QUESTION	:	'?'	;
STAR	:	'*';
PLUS	:	'+';
LBRACE	:	'{'	;
RBRACE	:	'}'	;
CARET	:	'^'	;
URL_LITERAL
	:	( '/' ( 'a' .. 'z' | 'A' .. 'Z' | '0' .. '9' | '_' | '.' )+ )+
	;
SINGLEQUOTED_STRING
	:	'\'' ( options {greedy=false;} : . )* '\''
	;
DOUBLEQUOTED_STRING
	:	'"'
		(	EscapeSequence
		|	~( '\\' | '"' | '\r' | '\n' )
		)*
		'"'
	;
fragment EscapeSequence
	:	'\\'	(
				'b'
			|	't'
			|	'n'
			|	'f'
			|	'r'
			|	'\"'
			|	'\''
			|	'\\'
			|	('0'..'3') ('0'..'7') ('0'..'7')
			|	('0'..'7') ('0'..'7')
			|	('0'..'7')
			)
	;
ANGLE_STRING
	:	'<' ( options {greedy=false;} : . )* '>'
	;
ID	:	( 'a' .. 'z' | 'A' .. 'Z' | '_' )
		( 'a' .. 'z' | 'A' .. 'Z' | '0' .. '9' | '_' )*
	;
FLOAT
	:	'-'? '0' .. '9' '.' ( '0' .. '9' )+
	;
INT
	:	'-'? ( '0' .. '9' )+
	;
WS	:	(' '|'\r'|'\t'|'\n') {$channel=HIDDEN;}
	;
SL_COMMENT
	:	'//' ~('\n'|'\r')* '\r'? '\n' {$channel=HIDDEN;}
	;
ML_COMMENT
	:	'/*' ( options {greedy=false;} : . )* '*/' {$channel=HIDDEN;}
	;
