/* Copyright 2009 Patrick Higgins 
 *
 * This file is part of VladNput.
 *
 * VladNput is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * VladNput is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with VladNput.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.vladnput.types;

import java.util.Collections;
import java.util.Date;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.vladnput.VladMessageVars;
import org.vladnput.VladUtil;

public class IntegerType extends VladType {

	public static final String INTEGER_KEY = "integer";
	public static final String MIN_KEY = "min";
	public static final String MAX_KEY = "max";
	
	public static final Set<String> VALID_KEYS;
	static {
		Set<String> validKeys = new HashSet<String>();

		validKeys.add(MIN_KEY);
		validKeys.add(MAX_KEY);

		VALID_KEYS = Collections.unmodifiableSet(validKeys);
	}
	
	private final Integer min;
	private final Integer max;

	public IntegerType(Map<String,Object> args) {
		super(args);
		this.min = (integerKey(args, MIN_KEY));
		this.max = (integerKey(args, MAX_KEY));
	}
	
	public static void checkArg(String name, Object value, Map<String,Object> args) throws InvalidArgException, InvalidArgValueException {
		if (VALID_KEYS.contains(name)) {
			int i = ((Integer) value).intValue();
			if (MAX_KEY.equals(name)) {
				Object minObj = (Object) args.get(MIN_KEY);
				if (minObj instanceof Integer) { // don't cause ClassCastException for min
					int min = ((Integer) minObj).intValue();
					if (i < min)
						throw new InvalidArgValueException(name, value);
				}
			}
		}
		else {
			VladType.checkArg(name, value, args);
		}
	}
	
	@Override
	public List<String> doValidate(List<String> msgs, String value, VladMessageVars vars) {
		msgs = super.doValidate(msgs, value, vars);
		try {
			int v = Integer.parseInt(value);
			if (min != null && v < min.intValue()) {
				msgs = addMessage(msgs, MIN_KEY);
				vars.put(MIN_KEY, min.toString());
				
			}
			if (max != null && v > max.intValue()) {
				msgs = addMessage(msgs, MAX_KEY);
				vars.put(MAX_KEY, max.toString());
			}
		}
		catch (NumberFormatException e) {
			msgs = addMessage(msgs, INTEGER_KEY);
		}
		return msgs;
	}


}
