/* Copyright 2009 Patrick Higgins 
 *
 * This file is part of VladNput.
 *
 * VladNput is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * VladNput is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with VladNput.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.vladnput;

import javax.servlet.http.HttpServletRequest;

import junit.framework.TestCase;

public class EnforceTest extends TestCase {
	
	private void check(String filename, boolean noneValue) throws Exception {
		VladConfig config = VladConfig.parseResource(filename);
		ClassLoader loader = this.getClass().getClassLoader();
		RequestLogParser parser = new RequestLogParser(loader.getResource("semantics/enforce/enforce.req"));

		for (HttpServletRequest request: parser) {
			VladErrors errors = config.validate(request, null);
			assertTrue(errors.hasEnforcedErrors());
			for (VladError error : errors) {
				if ("yes".equals(error.getParamName())) {
					assertTrue(error.getEnforce());
				}
				else if ("no".equals(error.getParamName())) {
					assertFalse(error.getEnforce());
				}
				else if ("none".equals(error.getParamName())) {
					assertEquals(noneValue, error.getEnforce());
				}
				else {
					throw new IllegalStateException();
				}
			}
		}
	}

	public void testYes() throws Exception {
		check("semantics/enforce/enforce-yes.vlad", true);
	}

	public void testNo() throws Exception {
		check("semantics/enforce/enforce-no.vlad", false);
	}

	public void testNone() throws Exception {
		check("semantics/enforce/enforce-none.vlad", true);
	}

	public void testNever() throws Exception {
		VladConfig config = VladConfig.parseResource("semantics/enforce/enforce-never.vlad");
		ClassLoader loader = this.getClass().getClassLoader();
		RequestLogParser parser = new RequestLogParser(loader.getResource("semantics/enforce/enforce.req"));

		for (HttpServletRequest request: parser) {
			VladErrors errors = config.validate(request, null);
			assertFalse(errors.hasEnforcedErrors());
			for (VladError error: errors) {
				assertFalse(error.getEnforce());
			}
		}
	}

}
