/* Copyright 2009 Patrick Higgins 
 *
 * This file is part of VladNput.
 *
 * VladNput is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * VladNput is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with VladNput.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.vladnput;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.Iterator;

import javax.servlet.http.HttpServletRequest;

import junit.framework.AssertionFailedError;
import junit.framework.TestCase;

public class InheritTest extends TestCase {
	
	private void check(String vlad, String req, String regex) throws Exception {
		VladConfig config = VladConfig.parseResource(vlad);
		ClassLoader loader = this.getClass().getClassLoader();
		RequestLogParser parser = new RequestLogParser(loader.getResource(req));
		for (HttpServletRequest request : parser) {
			VladErrors errors = config.validate(request, null);
			for (VladError error : errors) {
				assertTrue(error.getMessage(), error.getMessage().matches(regex));
			}
		}
	}

	public void testMsg() throws Exception {
		char[] correctType = { 'a','b','c','d','e','f' };
		for (int i = 1; i <= 6; i++) {
			check("semantics/inherit/msg/"+i+".vlad",
				  "semantics/inherit/msg/msg.req",
				  "a d"+i+" [^"+correctType[i-1]+"]1: m"+i);
		}
	}

	public void testReqMsg() throws Exception {
		for (int i = 1; i <= 6; i++) {
			check("semantics/inherit/req/"+i+".vlad",
				  "semantics/inherit/req/req.req",
				  "a a: m"+i);
		}
	}

	public void testTooFewMsg() throws Exception {
		for (int i = 1; i <= 6; i++) {
			check("semantics/inherit/toofew/"+i+".vlad",
				  "semantics/inherit/toofew/toofew.req",
				  "a a: m"+i);
		}
	}

	public void testTooManyMsg() throws Exception {
		for (int i = 1; i <= 6; i++) {
			check("semantics/inherit/toomany/"+i+".vlad",
				  "semantics/inherit/toomany/toomany.req",
				  "a a: m"+i);
		}
	}

	public void testSensitive() throws Exception {
		for (int i = 1; i <= 6; i++) {
			check("semantics/inherit/sensitive/"+i+".vlad",
				  "semantics/inherit/sensitive/sensitive.req",
				  "a d"+i+" SENSITIVE: m"+i);
		}
	}

	public void testCard() throws Exception {
		StubHttpServletRequest failReq = new StubHttpServletRequest("GET", "/1");
		StubHttpServletRequest passReq = new StubHttpServletRequest("GET", "/1");
		passReq.addParam("a", "a");
		
		for (int i = 1; i <= 6; i++) {
			VladConfig config = VladConfig.parseResource("semantics/inherit/card/"+i+".vlad");
			VladErrors failErrors = config.validate(failReq, null);
			VladErrors passErrors = config.validate(passReq, null);
			
			assertEquals(0, passErrors.getErrors().size());
			assertEquals(1, failErrors.getErrors().size());
			
			VladError err = (VladError) failErrors.getErrors().iterator().next();
			assertEquals("a a: default req_msg", err.getMessage());
		}
		

	}

	public void testInheritMissing() throws Exception {
		try {
			VladConfig.parseResource("semantics/inherit/missing/missing.vlad");
			throw new AssertionFailedError("ParseException not thrown");
		}
		catch (ParseException e) {
			StringWriter sw = new StringWriter();
			PrintWriter pw = new PrintWriter(sw);
			e.getErrors().reportErrors(pw);
			pw.close();
			TestUtil.logCompare("semantics/inherit/missing/missing.expect", sw.toString());
		}
	}

}
