/* Copyright 2009 Patrick Higgins 
 *
 * This file is part of VladNput.
 *
 * VladNput is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * VladNput is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with VladNput.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.vladnput;

import java.util.HashMap;
import java.util.Map;

import org.apache.log4j.AppenderSkeleton;
import org.apache.log4j.Level;
import org.apache.log4j.spi.LoggingEvent;

import org.vladnput.VladLogger.LogKey;

public class LogCountAppender extends AppenderSkeleton {
	
	private final Map<LogKey,Integer> counts = VladUtil.newHashMap();
	private final Map<LogKey,Integer> sensitiveCounts = VladUtil.newHashMap();
	
	public Map<LogKey,Integer> getCounts() {
		return counts;
	}

	public Map<LogKey,Integer> getSensitiveCounts() {
		return sensitiveCounts;
	}
	
	private int getCounts(String url, String param, Map<LogKey,Integer> map) {
		LogKey key = new LogKey("["+url+"]", "["+param+"]");
		Integer i = (Integer) map.get(key);
		if (i == null)
			return 0;
		else
			return i.intValue();		
	}

	public int getCounts(String url, String param) {
		return getCounts(url, param, counts);
	}

	public int getSensitiveCounts(String url, String param) {
		return getCounts(url, param, sensitiveCounts);
	}
	
	private void incrementCount(LogKey key, Map<LogKey,Integer> map) {
		Integer i = (Integer) map.get(key);
		if (i == null) {
			map.put(key, Integer.valueOf(1));
		}
		else {
			map.put(key, Integer.valueOf(i.intValue()+1));
		}		
	}

	protected void append(LoggingEvent event) {
		String msg = event.getRenderedMessage();
		if (event.getLevel() == Level.WARN) {
			String[] parts = msg.split(" ", 5);
			LogKey key = new LogKey(parts[1], parts[2]);
			incrementCount(key, counts);
			if (("["+VladConfig.SENSITIVE_VALUE+"]").equals(parts[3]))
				incrementCount(key, sensitiveCounts);
		}
		else {
			System.err.println(msg);
		}
	}

	public void close() {
		// nothing to do
	}

	public boolean requiresLayout() {
		return false;
	}

	public void reset() {
		counts.clear();
		sensitiveCounts.clear();
	}
	
	public String toString() {
		return counts.toString() + sensitiveCounts.toString();
	}

}
