/* Copyright 2009 Patrick Higgins 
 *
 * This file is part of VladNput.
 *
 * VladNput is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * VladNput is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with VladNput.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.vladnput;

import javax.servlet.http.HttpServletRequest;

import junit.framework.TestCase;

public class LoggerTest extends TestCase {

	private void assertCounts(int regular, int sensitive, LogCountAppender counter, String url, String param) {
		assertEquals(regular, counter.getCounts(url, param));
		assertEquals(sensitive, counter.getSensitiveCounts(url, param));
	}
	
	public void test() throws Exception {
		VladConfig config = VladConfig.parseResource("semantics/logger/logger.vlad");
		ClassLoader loader = this.getClass().getClassLoader();
		RequestLogParser parser = new RequestLogParser(loader.getResource("semantics/logger/logger.req"));

		LogCountAppender counter = (LogCountAppender) VladLogger.log.getAppender("COUNTER");
		counter.reset();

		for (HttpServletRequest request: parser) {
			config.validate(request, null);
		}
		
		assertCounts(3, 0, counter, "/0", "a");
		assertCounts(3, 0, counter, "/1", "a");
		assertCounts(3, 0, counter, "/0", "b");
		assertCounts(3, 0, counter, "/1", "b");

		assertCounts(0, 0, counter, "/2", "a");
		assertCounts(1, 0, counter, "/2", "b");
		assertCounts(2, 0, counter, "/2", "c");
		assertCounts(5, 0, counter, "/2", "d");
		assertCounts(4, 0, counter, "/2", "e");

		assertCounts(0, 0, counter, "/3", "aa");
		assertCounts(1, 0, counter, "/3", "bb");
		assertCounts(2, 0, counter, "/3", "cc");
		assertCounts(5, 0, counter, "/3", "dd");
		assertCounts(4, 0, counter, "/3", "ee");

		assertCounts(5, 0, counter, "/unrecognized", null);
		assertCounts(5, 0, counter, "/unrecognized2", null);

		assertCounts(1, 1, counter, "/sensitive", "a");
		assertCounts(1, 1, counter, "/sensitive", "b");
	}

}
