/* Copyright 2009 Patrick Higgins 
 *
 * This file is part of VladNput.
 *
 * VladNput is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * VladNput is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with VladNput.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.vladnput;

import java.util.Enumeration;
import java.util.Iterator;

import javax.servlet.http.HttpServletRequest;

import junit.framework.TestCase;

public class RequestLogParserTest extends TestCase {
	
	private RequestLogParser parser;
	
	public RequestLogParserTest(String name) {
		super(name);
	}

	protected void setUp() throws Exception {
		super.setUp();
		parser = new RequestLogParser(RequestLogParserTest.class.getResource("RequestLogParserTest.log"));
	}

	protected void tearDown() throws Exception {
		super.tearDown();
		parser.close();
	}

	public void testIterator() {
		Iterator<HttpServletRequest> i = parser.iterator();
		while (i.hasNext()) {
			HttpServletRequest req = (HttpServletRequest) i.next();
			assertEquals("GET", req.getMethod());
			assertEquals("127.0.0.1", req.getRemoteAddr());
			
			String url = req.getRequestURI();
			
			String expect = null;
			if ("/empty".equals(url))
				expect = "";
			else if ("/spaces".equals(url))
				expect = " ";
			else if ("/doubleencoded".equals(url))
				expect = "%20";
			else if ("/tripleencoded".equals(url))
				expect = "%2520";
			
			assertNotNull("Unknown URL: "+url, expect);
			
			for (Enumeration e = req.getParameterNames(); e.hasMoreElements(); ) {
				String name = (String) e.nextElement();
				String[] vals = req.getParameterValues(name);
				for (int j = 0; j < vals.length; j++) {
					assertEquals(expect, vals[j]);
				}
			}
		}
	}

}
