/* Copyright 2009 Patrick Higgins 
 *
 * This file is part of VladNput.
 *
 * VladNput is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * VladNput is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with VladNput.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.vladnput;

import java.io.BufferedReader;
import java.io.IOException;
import java.security.Principal;
import java.util.Collections;
import java.util.Enumeration;
import java.util.LinkedHashMap;
import java.util.Locale;
import java.util.Map;

import javax.servlet.RequestDispatcher;
import javax.servlet.ServletInputStream;
import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

public class StubHttpServletRequest implements HttpServletRequest {

	private final String method;
	private final String url;
	private final Map<String,Object> params = VladUtil.newLinkedHashMap();
	
	public StubHttpServletRequest(String method, String url) {
		this.method = method;
		this.url = url;
	}
	
	void addParam(String name, String value) {
		if (params.containsKey(name)) {
			Object o = params.get(name);
			if (o instanceof String) {
				params.put(name, new String[] { (String) o, value } );
			}
			else {
				String[] strs = (String[]) o;
				String[] newstrs = new String[strs.length+1];
				System.arraycopy(strs, 0, newstrs, 0, strs.length);
				newstrs[strs.length] = value;
				params.put(name, newstrs);
			}
		}
		else {
			params.put(name, value);
		}
	}
	
	public String getMethod() {
		return method;
	}

	public String getRequestURI() {
		return url;
	}

	public String getServletPath() {
		return url;
	}

	public String getParameter(String name) {
		Object val = params.get(name);
		if (val == null) {
			return null;
		}
		if (val instanceof String) {
			return (String) val;
		}
		return ((String[]) val)[0];
	}

	public Map getParameterMap() {
		return params;
	}

	public Enumeration getParameterNames() {
		return Collections.enumeration(params.keySet());
	}

	public String[] getParameterValues(String name) {
		Object vals = params.get(name);
		if (vals == null) {
			return null;
		}
		if (vals instanceof String) {
			return new String[] { (String) vals };
		}
		return (String[]) vals;
	}

	public String getProtocol() {
		return "HTTP/1.1";
	}

	public String getRemoteAddr() {
		return "127.0.0.1";
	}

	public String getRemoteHost() {
		return "127.0.0.1";
	}

	public String getAuthType() {
		throw new UnsupportedOperationException();
	}

	public String getContextPath() {
		throw new UnsupportedOperationException();
	}

	public Cookie[] getCookies() {
		throw new UnsupportedOperationException();
	}

	public long getDateHeader(String arg0) {
		throw new UnsupportedOperationException();
	}

	public String getHeader(String arg0) {
		throw new UnsupportedOperationException();
	}

	public Enumeration getHeaderNames() {
		throw new UnsupportedOperationException();
	}

	public Enumeration getHeaders(String arg0) {
		throw new UnsupportedOperationException();
	}

	public int getIntHeader(String arg0) {
		throw new UnsupportedOperationException();
	}

	public String getPathInfo() {
		throw new UnsupportedOperationException();
	}

	public String getPathTranslated() {
		throw new UnsupportedOperationException();
	}

	public String getQueryString() {
		throw new UnsupportedOperationException();
	}

	public String getRemoteUser() {
		throw new UnsupportedOperationException();
	}

	public StringBuffer getRequestURL() {
		throw new UnsupportedOperationException();
	}

	public String getRequestedSessionId() {
		throw new UnsupportedOperationException();
	}

	public HttpSession getSession() {
		throw new UnsupportedOperationException();
	}

	public HttpSession getSession(boolean arg0) {
		throw new UnsupportedOperationException();
	}

	public Principal getUserPrincipal() {
		throw new UnsupportedOperationException();
	}

	public boolean isRequestedSessionIdFromCookie() {
		throw new UnsupportedOperationException();
	}

	public boolean isRequestedSessionIdFromURL() {
		throw new UnsupportedOperationException();
	}

	public boolean isRequestedSessionIdFromUrl() {
		throw new UnsupportedOperationException();
	}

	public boolean isRequestedSessionIdValid() {
		throw new UnsupportedOperationException();
	}

	public boolean isUserInRole(String arg0) {
		throw new UnsupportedOperationException();
	}

	public Object getAttribute(String arg0) {
		throw new UnsupportedOperationException();
	}

	public Enumeration getAttributeNames() {
		throw new UnsupportedOperationException();
	}

	public String getCharacterEncoding() {
		throw new UnsupportedOperationException();
	}

	public int getContentLength() {
		throw new UnsupportedOperationException();
	}

	public String getContentType() {
		throw new UnsupportedOperationException();
	}

	public ServletInputStream getInputStream() throws IOException {
		throw new UnsupportedOperationException();
	}

	public String getLocalAddr() {
		throw new UnsupportedOperationException();
	}

	public String getLocalName() {
		throw new UnsupportedOperationException();
	}

	public int getLocalPort() {
		throw new UnsupportedOperationException();
	}

	public Locale getLocale() {
		throw new UnsupportedOperationException();
	}

	public Enumeration getLocales() {
		throw new UnsupportedOperationException();
	}

	public BufferedReader getReader() throws IOException {
		throw new UnsupportedOperationException();
	}

	public String getRealPath(String arg0) {
		throw new UnsupportedOperationException();
	}

	public int getRemotePort() {
		throw new UnsupportedOperationException();
	}

	public RequestDispatcher getRequestDispatcher(String arg0) {
		throw new UnsupportedOperationException();
	}

	public String getScheme() {
		throw new UnsupportedOperationException();
	}

	public String getServerName() {
		throw new UnsupportedOperationException();
	}

	public int getServerPort() {
		throw new UnsupportedOperationException();
	}

	public boolean isSecure() {
		throw new UnsupportedOperationException();
	}

	public void removeAttribute(String arg0) {
		throw new UnsupportedOperationException();
	}

	public void setAttribute(String arg0, Object arg1) {
		throw new UnsupportedOperationException();
	}

	public void setCharacterEncoding(String arg0) {
		throw new UnsupportedOperationException();
	}


}
