#!/usr/bin/ruby

require 'rubygems'
require 'sqlite3'

db = SQLite3::Database.new("rlog.db")

db.execute_batch(<<EOF

BEGIN TRANSACTION;

CREATE TABLE IF NOT EXISTS Urls (
  id INTEGER PRIMARY KEY,
  url TEXT
);

CREATE TABLE IF NOT EXISTS Requests (
  id INTEGER PRIMARY KEY,
  url_id INTEGER,
  access TEXT,
  addr TEXT,
  method TEXT
);

CREATE TABLE IF NOT EXISTS Params (
  id INTEGER PRIMARY KEY,
  request_id INTEGER,
  url_id INTEGER,
  name TEXT,
  value TEXT
);

CREATE TABLE IF NOT EXISTS Url_Params (
  id INTEGER PRIMARY KEY,
  url_id INTEGER,
  name TEXT
);

COMMIT;

EOF
)

u_stmt = db.prepare("INSERT INTO Urls(url) VALUES(?)")
r_stmt = db.prepare("INSERT INTO Requests(url_id, access, addr, method) VALUES(?,?,?,?)")
p_stmt = db.prepare("INSERT INTO Params(request_id, url_id, name, value) VALUES(?,?,?,?)")
up_stmt = db.prepare("INSERT INTO Url_Params(url_id, name) VALUES(?,?)")

url_ids = {}
url_params = {}
url_id = nil
request_id = nil

db.execute("BEGIN TRANSACTION")

db.query("SELECT id, url FROM Urls") { |rs|
  while vals = rs.next
    url_ids[vals[1]] = vals[0].to_i
  end
}

db.query("SELECT url_id, name FROM Url_Params") { |rs|
  while vals = rs.next
    params = url_params[vals[0].to_i] ||= {}
    params[vals[1]] = 1
  end
}

params = nil

ARGV.each { |file|
  IO.foreach(file) { |line|
    if line =~ /^(\d+-\d+-\d+ \d+:\d+:\d+) (\d+(?:\.\d+)+) (GET|POST) (.+)/
      access, addr, method, url = $1, $2, $3, $4
      url.sub!(/%3Bjsessionid%3D.*/, "")
      unless url_ids.has_key?(url)
        puts "Inserting URL #{url}"
        u_stmt.execute(url)
        url_ids[url] = db.last_insert_row_id().to_i
      end

      url_id = url_ids[url]
      params = url_params[url_id] ||= {}
      r_stmt.execute(url_id, access, addr, method)
      request_id = db.last_insert_row_id().to_i
    elsif line =~ /^\t([^=]*)=(.*)/
      name, value = $1, $2
      p_stmt.execute(request_id, url_id, name, value)
      unless params.has_key?(name)
        up_stmt.execute(url_id, name)
        params[name] = 1
      end
    end

    if db.total_changes % 100000 == 0
      puts "Committing at #{db.total_changes}"
      db.execute_batch("COMMIT; BEGIN TRANSACTION;")
    end
  }
}

db.execute("COMMIT")

db.execute_batch(<<EOF

BEGIN TRANSACTION;

CREATE INDEX IF NOT EXISTS Param_Url_Idx ON Params (url_id);

COMMIT;

EOF
)
